<?php

/**
*  TargetPay IVR example class
* 
*  SVE
*  11-01-2009
*/
  
# requires the init class
require_once ( 'TargetPay.class.php' );
  
class TargetPayIvr extends TargetPay {
    
  # ofcourse construct
  public function __construct( $intRtlo ) {
    
    # call parent constructor 
    parent::__construct( $intRtlo );
      
  }
  
  /**
  * @Desc start payment
  * @Return array ( payline, paycode, price )
  * 
  * Response will look like: ( 0909-8888, 55555, 80 Cent)
  */
  
  public function startPayment () {
      
      try {
                    
          # Build parameter string
          $aParameters = $this->getBaseRequest();
          $aParameters['method'] = 'IVR';
          if ( $this->IvrAmount > 0 ) $aParameters['ivramount'] = $this->IvrAmount;
          if ( $this->IvrCallTariff > 0 ) $aParameters['calltariff'] = $this->IvrCallTariff;
          if ( $this->IvrCallType > 0 ) $aParameters['calltype'] = $this->IvrCallType;
          if ( $this->IvrCallDuration > 0 ) $aParameters['callduration'] = $this->IvrCallDuration;

          # do request
          $strResponse = $this->getResponse( $aParameters );
          $aResponse = explode('|', $strResponse );

          # Bad response
          if ( !isset ( $aResponse[3] ) ) {
            throw new Exception( 'Error' . $aResponse[0] );    
          }
          
          # We return Payline, code, and price
          return array ( $aResponse[2], $aResponse[3], $aResponse[4] );
              
      } 
      catch( Exception $e ) {
      
        # error, could not proceed 
        echo $e->getMessage();
      
      }    
  }
  
  /**
   * Validate the payment now by trxId
   *
   * @return bool
   */
   
   public function validatePayment ( $strPayline, $strPayCode ) {
       
       try {
        
           # Build parameter string
           $aParameters = $this->getBaseRequest();
           $aParameters['action'] = 'check';
           $aParameters['method'] = 'IVR';
           $aParameters['payline'] = $strPayline;
           $aParameters['paycode'] = $strPayCode;
           
           # do request
           $strResponse = $this->getResponse ( $aParameters );
           $aResponse = explode('|', $strResponse );
           
           # Bad response
           if (  $aResponse[0] != 'OK' ) {
                throw new Exception( $aResponse[0] );    
           }
           
           return true;
       
       }    
       catch( Exception $e ) {
      
        # error, could not proceed 
        echo $e->getMessage();
      
      } 
               
   }
   
   /**
   * @desc set ivr amount in cents
   *   OPTIONAL
   */
   
   public function setIvrAmount ( $intAmount ) {
       if ( is_numeric ( $intAmount ) && $intAmount > 0 )  {  
            $this->IvrAmount = $intAmount;
       }   
   }
   
   /**
   * @desc set call tarif in seconds
   *   OPTIONAL
   */
   
   public function setIvrCallTariff( $intAmount ) {
       if ( is_numeric ( $intAmount ) && $intAmount > 0 )  {  
            $this->IvrCallTariff = $intAmount;
       }   
   }
   
   /**
   * @desc set call type, this should be either: "PU", "PM", or "PC"
   *   OPTIONAL
   */
   
   public function setIvrCallType( $strType ) {
       if ( $strType == 'PU' || $strType == 'PM' || $strType = 'PC' )  {  
            $this->IvrCallType = $strType;
       }   
   }
   
   /**
   * @desc set call duration in seconds
   *   OPTIONAL
   */
   
   public function setIvrCallDuration( $intAmount ) {
       if ( is_numeric ( $intAmount ) && $intAmount > 0 )  {  
            $this->IvrCallDuration = $intAmount;
       }   
   }
   
}
  
?>
